package com.miaxis.app.area.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.miaxis.app.area.mapper.AreaCodeMapper;
import com.miaxis.app.area.domain.AreaCode;
import com.miaxis.app.area.service.IAreaCodeService;

/**
 * 区域编码Service业务层处理
 *
 * @author zhangbin
 * @date 2020-12-28
 */
@Service
public class AreaCodeServiceImpl extends ServiceImpl<AreaCodeMapper, AreaCode> implements IAreaCodeService {
    @Autowired
    private AreaCodeMapper areaCodeMapper;

    /**
     * 查询区域编码
     *
     * @param code 区域编码ID
     * @return 区域编码
     */
    @Override
    public AreaCode selectAreaCodeById(String code){
        return areaCodeMapper.selectAreaCodeById(code);
    }

    /**
     * 查询区域编码列表
     *
     * @param areaCode 区域编码
     * @return 区域编码
     */
    @Override
    public List<AreaCode> selectAreaCodeList(AreaCode areaCode){
        return areaCodeMapper.selectAreaCodeList(areaCode);
    }

    /**
     * 新增区域编码
     *
     * @param areaCode 区域编码
     * @return 结果
     */
    @Override
    public int insertAreaCode(AreaCode areaCode){
        return areaCodeMapper.insertAreaCode(areaCode);
    }

    /**
     * 修改区域编码
     *
     * @param areaCode 区域编码
     * @return 结果
     */
    @Override
    public int updateAreaCode(AreaCode areaCode){
        return areaCodeMapper.updateAreaCode(areaCode);
    }

    /**
     * 批量删除区域编码
     *
     * @param codes 需要删除的区域编码ID
     * @return 结果
     */
    @Override
    public int deleteAreaCodeByIds(String[] codes){
        return areaCodeMapper.deleteAreaCodeByIds(codes);
    }

    /**
     * 删除区域编码信息
     *
     * @param code 区域编码ID
     * @return 结果
     */
    @Override
    public int deleteAreaCodeById(String code){
        return areaCodeMapper.deleteAreaCodeById(code);
    }
}
